/* 
 * DNet eBusiness Suite
 * Copyright: Nan21 Electronics SRL. All rights reserved.
 * Use is subject to license terms.
 */
package net.nan21.dnet.module.fi.asset.ds.converter;

import net.nan21.dnet.core.api.converter.IDsConverter;
import net.nan21.dnet.core.presenter.converter.AbstractDsConverter;
import net.nan21.dnet.module.bd.currency.business.service.ICurrencyService;
import net.nan21.dnet.module.bd.currency.domain.entity.Currency;
import net.nan21.dnet.module.bd.org.business.service.IOrganizationService;
import net.nan21.dnet.module.bd.org.domain.entity.Organization;
import net.nan21.dnet.module.fi.asset.business.service.IAssetCategoryService;
import net.nan21.dnet.module.fi.asset.domain.entity.Asset;
import net.nan21.dnet.module.fi.asset.domain.entity.AssetCategory;
import net.nan21.dnet.module.fi.asset.ds.model.AssetDs;
import net.nan21.dnet.module.md.mm.prod.business.service.IProductService;
import net.nan21.dnet.module.md.mm.prod.domain.entity.Product;

public class AssetDsConv extends AbstractDsConverter<AssetDs, Asset>
		implements
			IDsConverter<AssetDs, Asset> {

	@Override
	protected void modelToEntityReferences(AssetDs ds, Asset e, boolean isInsert)
			throws Exception {
		if (ds.getOrgId() != null) {
			if (e.getOrg() == null || !e.getOrg().getId().equals(ds.getOrgId())) {
				e.setOrg((Organization) this.em.find(Organization.class,
						ds.getOrgId()));
			}
		} else {
			this.lookup_org_Organization(ds, e);
		}
		if (ds.getCategoryId() != null) {
			if (e.getCategory() == null
					|| !e.getCategory().getId().equals(ds.getCategoryId())) {
				e.setCategory((AssetCategory) this.em.find(AssetCategory.class,
						ds.getCategoryId()));
			}
		} else {
			this.lookup_category_AssetCategory(ds, e);
		}
		if (ds.getCurrencyId() != null) {
			if (e.getCurrency() == null
					|| !e.getCurrency().getId().equals(ds.getCurrencyId())) {
				e.setCurrency((Currency) this.em.find(Currency.class,
						ds.getCurrencyId()));
			}
		} else {
			this.lookup_currency_Currency(ds, e);
		}
		if (ds.getProductId() != null) {
			if (e.getProduct() == null
					|| !e.getProduct().getId().equals(ds.getProductId())) {
				e.setProduct((Product) this.em.find(Product.class,
						ds.getProductId()));
			}
		} else {
			this.lookup_product_Product(ds, e);
		}
	}

	protected void lookup_org_Organization(AssetDs ds, Asset e)
			throws Exception {
		if (ds.getOrg() != null && !ds.getOrg().equals("")) {
			Organization x = null;
			try {
				x = ((IOrganizationService) findEntityService(Organization.class))
						.findByCode(ds.getOrg());
			} catch (javax.persistence.NoResultException exception) {
				throw new Exception(
						"Invalid value provided to find `Organization` reference: `org` = "
								+ ds.getOrg() + "");
			}
			e.setOrg(x);
		} else {
			e.setOrg(null);
		}
	}

	protected void lookup_category_AssetCategory(AssetDs ds, Asset e)
			throws Exception {
		if (ds.getCategory() != null && !ds.getCategory().equals("")) {
			AssetCategory x = null;
			try {
				x = ((IAssetCategoryService) findEntityService(AssetCategory.class))
						.findByCode(ds.getCategory());
			} catch (javax.persistence.NoResultException exception) {
				throw new Exception(
						"Invalid value provided to find `AssetCategory` reference: `category` = "
								+ ds.getCategory() + "");
			}
			e.setCategory(x);
		} else {
			e.setCategory(null);
		}
	}

	protected void lookup_currency_Currency(AssetDs ds, Asset e)
			throws Exception {
		if (ds.getCurrency() != null && !ds.getCurrency().equals("")) {
			Currency x = null;
			try {
				x = ((ICurrencyService) findEntityService(Currency.class))
						.findByCode(ds.getCurrency());
			} catch (javax.persistence.NoResultException exception) {
				throw new Exception(
						"Invalid value provided to find `Currency` reference: `currency` = "
								+ ds.getCurrency() + "");
			}
			e.setCurrency(x);
		} else {
			e.setCurrency(null);
		}
	}

	protected void lookup_product_Product(AssetDs ds, Asset e) throws Exception {
		if (ds.getProductCode() != null && !ds.getProductCode().equals("")) {
			Product x = null;
			try {
				x = ((IProductService) findEntityService(Product.class))
						.findByCode(ds.getProductCode());
			} catch (javax.persistence.NoResultException exception) {
				throw new Exception(
						"Invalid value provided to find `Product` reference: `productCode` = "
								+ ds.getProductCode() + "");
			}
			e.setProduct(x);
		} else {
			e.setProduct(null);
		}
	}
}
